import React, { useRef, useEffect, useState } from 'react';
import { motion } from "framer-motion";
import { Link } from "react-router-dom";
import { createPageUrl } from "@/utils";
import { Button } from "@/features/shared/components/ui/button";
import { Download, Github, Linkedin, Mail, ArrowRight, MapPin, Globe, Coffee, Cloud, Code2, Brain, Gamepad2, Smartphone, Dumbbell } from "lucide-react";
import { cardStyles } from "@/features/shared/components/ui/card-styles";
import { siteConfig } from "@/features/shared/components/config/siteConfig";
import SEOHead from "@/features/shared/components/seo/SEOHead";

// Create an icon map to reference Lucide icons
const iconMap = {
  Cloud: Cloud,
  Code2: Code2,
  Brain: Brain
};

// Enhanced IntersectionObserver hook with multiple thresholds and performance monitoring
function useIntersectionObserver(options = {}) {
  const [isIntersecting, setIsIntersecting] = useState(false);
  const [intersectionRatio, setIntersectionRatio] = useState(0);
  const [performanceData, setPerformanceData] = useState(null);
  const ref = useRef(null);

  useEffect(() => {
    // Enhanced options with multiple thresholds for smoother animations
    const defaultOptions = {
      threshold: [0, 0.1, 0.25, 0.5, 0.75, 1.0],
      rootMargin: '50px',
      ...options
    };

    const observer = new IntersectionObserver((entries) => {
      const [entry] = entries;
      const startTime = performance.now();
      
      setIsIntersecting(entry.isIntersecting);
      setIntersectionRatio(entry.intersectionRatio);
      
      // Performance monitoring for intersection observer
      const endTime = performance.now();
      const processingTime = endTime - startTime;
      
      setPerformanceData({
        processingTime,
        intersectionRatio: entry.intersectionRatio,
        isIntersecting: entry.isIntersecting,
        timestamp: Date.now()
      });

      // Log performance data for monitoring (only in development)
      if (process.env.NODE_ENV === 'development' && processingTime > 16) {
        console.warn(`Intersection Observer processing took ${processingTime.toFixed(2)}ms`, {
          target: entry.target.className,
          ratio: entry.intersectionRatio
        });
      }
    }, defaultOptions);

    if (ref.current) {
      observer.observe(ref.current);
    }

    return () => {
      if (ref.current) {
        observer.unobserve(ref.current);
      }
    };
  }, [options]);

  return [ref, isIntersecting, intersectionRatio, performanceData];
}

export default function Home() {
  // Use enhanced intersection observer for skills section
  const [skillsRef, skillsVisible, skillsRatio, skillsPerf] = useIntersectionObserver({
    threshold: [0, 0.1, 0.25, 0.5, 0.75, 1.0],
    rootMargin: '100px'
  });
  
  // Use enhanced intersection observer for featured work section
  const [workRef, workVisible, workRatio, workPerf] = useIntersectionObserver({
    threshold: [0, 0.1, 0.25, 0.5, 0.75, 1.0],
    rootMargin: '100px'
  });

  // Enhanced structured data for homepage
  const homepageStructuredData = [
    {
      "@context": "https://schema.org",
      "@type": "WebPage",
      "name": "Chen Magled - Tech Lead & Full Stack Engineer",
      "description": "Professional homepage of Chen Magled, experienced Tech Lead specializing in cloud engineering, AI/ML solutions, and scalable system architecture.",
      "url": "https://www.chenmagled.com",
      "mainEntity": {
        "@type": "Person",
        "name": "Chen Magled",
        "jobTitle": "Tech Lead & Full Stack Engineer",
        "worksFor": {
          "@type": "Organization",
          "name": "Migdal Group"
        }
      }
    }
  ];

  return (
    <>
      <SEOHead
        structuredData={homepageStructuredData}
        keywords={[
          "Tech Lead Tel Aviv",
          "Full Stack Engineer Israel",
          "Cloud Engineering Expert",
          "AI ML Developer",
          "React Node.js Specialist",
          "AWS Platform Engineering",
          "GenAI Innovation",
          "Scalable System Architecture"
        ]}
      />
      <div className="bg-transparent dark:bg-transparent"> {/* Added light theme bg */}
      <section
        className="min-h-screen py-2 lg:py-12 2xl:py-12 flex items-center relative overflow-hidden" // Restored original padding
        aria-label="Introduction"
      >
        {/* Background elements - Dark theme only */}
        <div
          className="absolute inset-0 hidden dark:block dark:bg-gradient-to-br"
          aria-hidden="true"
        />
        <motion.div
          initial={{ opacity: 0 }}
          animate={{ opacity: 0.1 }}
          transition={{ duration: 1 }}
          className="absolute inset-0 hidden dark:block dark:bg-center dark:[mask-image:linear-gradient(180deg,white,rgba(255,255,255,0))]"
          aria-hidden="true"
        />
        
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 relative">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-8 sm:gap-12 lg:gap-20 2xl:gap-28 items-center">
            {/* Left column - Text content */}
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.8 }}
              className="text-left order-2 lg:order-1"
            >
              {/* Location Chip - Updated for Light Theme */}
              <motion.div
                initial={{ opacity: 0, scale: 0.8 }}
                animate={{ opacity: 1, scale: 1 }}
                transition={{ delay: 0.2 }}
                className="mb-4 sm:mb-6"
              >
                <span className="px-4 py-2 rounded-full bg-blue-100 text-blue-700 dark:bg-blue-500/10 dark:text-blue-400 text-sm font-medium inline-flex items-center">
                  <MapPin className="w-4 h-4 mr-2" aria-hidden="true" />
                  {siteConfig.location}
                </span>
              </motion.div>

              {/* Headline - Enhanced for SEO with proper heading hierarchy */}
              <motion.h1
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ delay: 0.3, duration: 0.8 }}
                className="text-3xl sm:text-4xl md:text-5xl lg:text-6xl xl:text-7xl 2xl:text-8xl font-bold bg-clip-text text-transparent
                           bg-gradient-to-r from-blue-600 via-purple-600 to-green-500
                           dark:from-blue-400 dark:via-indigo-400 dark:to-purple-400
                           animate-gradient mb-3 sm:mb-4 leading-[1.1]"
             >
               {siteConfig.intro.tagline}
             </motion.h1>

              {/* Enhanced subtitle with keyword-rich content */}
              <motion.p
                initial={{ opacity: 0 }}
                animate={{ opacity: 1 }}
                transition={{ delay: 0.4, duration: 0.8 }}
                className="text-base sm:text-lg lg:text-xl 2xl:text-2xl text-gray-600 dark:text-gray-300 max-w-3xl mb-6 sm:mb-8 lg:mb-10 leading-relaxed"
              >
                Experienced <strong>Tech Lead</strong> and <strong>Full Stack Developer</strong> with expertise in <strong>cloud engineering</strong>, <strong>AI/ML solutions</strong>, and <strong>scalable system architecture</strong>. Currently leading <strong>GenAI initiatives</strong> and <strong>platform transformation</strong> at Migdal Group, with a proven track record of delivering impactful solutions across diverse industries.
              </motion.p>

              {/* Buttons - Updated for Light Theme */}
              <motion.div
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ delay: 0.6, duration: 0.8 }}
                className="flex flex-wrap gap-3 sm:gap-5"
              >

                {/* Contact Me Button */}
                <Button
                  variant="outline"
                  size="lg"
                  asChild
                  aria-label="Contact Me"
                  className="min-w-[44px] min-h-[44px] bg-transparent border-2 border-blue-600 text-blue-600 hover:bg-blue-50
                             dark:border-blue-600 dark:text-blue-400 dark:hover:bg-blue-600/10 group"
                >
                  <Link to={createPageUrl("Contact")} className="flex items-center gap-1">
                    <div className='p-1 pt-1.5'><Mail className="w-4 h-4 group-hover:scale-110 transition-transform" aria-hidden="true" /></div>
                    <span>Contact Me</span>
                  </Link>
                </Button>
              </motion.div>

              {/* Social Links - Updated for Light Theme */}
              <motion.div
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ delay: 0.8, duration: 0.8 }}
                className="flex gap-3 sm:gap-5 mt-6 sm:mt-8 lg:mt-10"
              >
                {/* LinkedIn */}
                <a
                  href={siteConfig.social.linkedin}
                  target="_blank"
                  rel="noopener noreferrer"
                >
                  <Button
                    variant="ghost"
                    size="icon"
                    className="min-w-[44px] min-h-[44px] rounded-full text-gray-500 hover:bg-blue-100 hover:text-[#0A66C2]
                               dark:text-gray-400 dark:hover:bg-[#0A66C2]/10 dark:hover:text-[#0A66C2] transition-colors"
                    aria-label="LinkedIn Profile"
                  >
                    <Linkedin className="w-5 h-5" aria-hidden="true" />
                  </Button>
                </a>
                {/* GitHub */}
                <a
                  href={siteConfig.social.github}
                  target="_blank"
                  rel="noopener noreferrer"
                >
                  <Button
                    variant="ghost"
                    size="icon"
                    className="min-w-[44px] min-h-[44px] rounded-full text-gray-500 hover:bg-gray-200 hover:text-gray-900
                               dark:text-gray-400 dark:hover:bg-slate-700/60 dark:hover:text-white transition-colors"
                    aria-label="GitHub Profile"
                  >
                    <Github className="w-5 h-5" aria-hidden="true" />
                  </Button>
                </a>
                {/* Website/Globe */}
                <a
                  href={siteConfig.social.twitter || "#"} // Assuming twitter link is website for now
                  target="_blank"
                  rel="noopener noreferrer"
                >
                  <Button
                    variant="ghost"
                    size="icon"
                    className="min-w-[44px] min-h-[44px] rounded-full text-gray-500 hover:bg-blue-100 hover:text-blue-600
                               dark:text-gray-400 dark:hover:bg-[#1DA1F2]/10 dark:hover:text-[#1DA1F2] transition-colors" // Dark theme uses twitter color, maybe adjust later
                    aria-label="Website"
                  >
                    <Globe className="w-5 h-5" aria-hidden="true" />
                  </Button>
                </a>
              </motion.div>
            </motion.div>

            {/* Right column - Profile photo - Updated for Light Theme */}
            <motion.div
              initial={{ opacity: 0, scale: 0.8 }}
              animate={{ opacity: 1, scale: 1 }}
              transition={{ delay: 0.5, duration: 0.8 }}
              className="relative mt-8 sm:mt-12 lg:mt-0 order-1 lg:order-2" // Fixed order classes for mobile/desktop layout
            >
              {/* Made width/height responsive, maintained aspect ratio */}
              <div className="relative w-full max-w-[200px] sm:max-w-[250px] md:max-w-[300px] lg:max-w-[400px] xl:max-w-[500px] 2xl:max-w-[600px] aspect-[4/5] mx-auto">
                {/* Profile photo container with gradient border/glow */}
                {/* Light theme uses a subtle shadow/ring, dark uses gradient border */}
                <div className="absolute inset-0 rounded-2xl overflow-hidden
                              shadow-lg ring-1 ring-black/5
                              dark:bg-gradient-to-br dark:from-blue-500 dark:to-purple-600 dark:p-1 dark:shadow-none dark:ring-0">
                  <div className="absolute inset-0 bg-white dark:bg-slate-900 rounded-[15px] dark:rounded-2xl overflow-hidden"> {/* Slightly different rounding for inset effect */}
                    <img
                      src="/images/chen_profile_mini.webp"
                      alt={`Profile photo of ${siteConfig.name}`}
                      className="w-full h-full object-cover object-center"
                      loading="eager"
                      fetchPriority="high"
                      width="400"
                      height="500"
                      style={{ aspectRatio: '4/5' }}
                      decoding="sync"
                    />
                  </div>
                </div>

                {/* Decorative elements - Kept subtle for light theme */}
                <div
                  className="absolute -top-4 -right-4 w-20 h-20 bg-purple-500/5 dark:bg-purple-500/20 rounded-full blur-xl transform-gpu will-change-transform"
                  style={{ width: '80px', height: '80px' }}
                />
                <div
                  className="absolute -bottom-4 -left-4 w-24 h-24 bg-blue-500/5 dark:bg-blue-500/20 rounded-full blur-xl transform-gpu will-change-transform"
                  style={{ width: '96px', height: '96px' }}
                />
              </div>
            </motion.div>
          </div>
        </div>
      </section>

      {/* Technical Expertise Section - Enhanced for SEO */}
      <section className="py-12 sm:py-16 lg:py-20 2xl:py-24 bg-background bg-transparent text-foreground" aria-labelledby="expertise-heading">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <motion.div
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.6 }}
            className="text-center mb-10 sm:mb-12 lg:mb-16"
          >
            <span className="inline-block px-4 py-2 rounded-full bg-blue-500/10 text-blue-400 text-sm font-medium mb-4">
              Core Competencies
            </span>
            <h2 id="expertise-heading" className="text-2xl sm:text-3xl lg:text-4xl font-bold mb-4 text-foreground">
              Technical Expertise & Specializations
            </h2>
            <p className="text-muted-foreground max-w-2xl mx-auto text-sm sm:text-base leading-relaxed px-4">
              Over <strong>10+ years of experience</strong> building <strong>scalable applications</strong>, leading <strong>engineering teams</strong>, and driving <strong>digital transformation</strong> across cloud platforms, AI/ML systems, and full-stack development
            </p>
          </motion.div>

          {/* Cards for areas of expertise */}
          <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4 sm:gap-6 lg:gap-8">
            {Object.values(siteConfig.skills).map((skill, index) => {
              // Get the correct icon component using the iconMap
              const IconComponent = iconMap[skill.iconName] || Cloud;
              
              const skillColors = {
                cloud: {
                  bg: "from-blue-500/5 via-transparent to-transparent",
                  border: "bg-blue-500/30",
                  iconBg: "bg-blue-500/10",
                  icon: "text-blue-400",
                  badge: "bg-blue-500/10 text-blue-400"
                },
                development: {
                  bg: "from-indigo-500/5 via-transparent to-transparent",
                  border: "bg-indigo-500/30",
                  iconBg: "bg-indigo-500/10",
                  icon: "text-indigo-400",
                  badge: "bg-indigo-500/10 text-indigo-400"
                },
                ai: {
                  bg: "from-purple-500/5 via-transparent to-transparent",
                  border: "bg-purple-500/30",
                  iconBg: "bg-purple-500/10",
                  icon: "text-purple-400",
                  badge: "bg-purple-500/10 text-purple-400"
                }
              };

              const currentColor = skillColors[Object.keys(siteConfig.skills)[index] || "cloud"];

              return (
                <motion.div
                  key={index}
                  initial={{ opacity: 0, y: 20 }}
                  whileInView={{ opacity: 1, y: 0 }}
                  viewport={{ once: true }}
                  transition={{ duration: 0.6, delay: index * 0.2 }}
                  whileHover={{ y: -8, transition: { duration: 0.3 } }}
                  className="bg-card border border-border text-card-foreground rounded-xl p-4 sm:p-6 overflow-hidden relative group"
                >
                  {/* Animated gradient background */}
                  <div
                    className={`absolute inset-0 bg-gradient-to-br ${currentColor.bg} opacity-50 dark:hidden
                      group-hover:opacity-100 transition-opacity duration-500`}
                  />

                  {/* Animated border */}
                  <div 
                    className="absolute inset-0 opacity-0 group-hover:opacity-100 transition-opacity duration-300"
                    style={{
                      background: `linear-gradient(45deg, ${currentColor.border}, transparent 60%)`,
                      maskImage: "linear-gradient(#fff 0 0) padding-box, linear-gradient(#fff 0 0)",
                      maskComposite: "exclude",
                    }}
                  />

                  <div className="relative z-10">
                    <motion.div 
                      initial={{ scale: 1 }}
                      whileHover={{ scale: 1.1 }}
                      transition={{ type: "spring", stiffness: 300 }}
                      className={`${currentColor.iconBg} w-12 h-12 sm:w-16 sm:h-16 rounded-xl flex items-center justify-center mb-4 sm:mb-6`}
                    >
                      <IconComponent className={`w-6 h-6 sm:w-8 sm:h-8 ${currentColor.icon}`} />
                    </motion.div>

                    <h3 className="text-lg sm:text-xl font-semibold mb-3 sm:mb-4 text-card-foreground">
                      {skill.title}
                    </h3>

                    <div className="flex flex-wrap gap-2 mb-6 sm:mb-8">
                      {skill.skills.slice(0, 3).map((s, i) => (
                        <motion.span 
                          key={i}
                          initial={{ opacity: 0, scale: 0.8 }}
                          animate={{ opacity: 1, scale: 1 }}
                          transition={{ delay: i * 0.1 }}
                          className={`px-3 py-1 rounded-full ${currentColor.badge} text-sm`}
                        >
                          {s}
                        </motion.span>
                      ))}
                    </div>

                    <Link
                      to={createPageUrl("Experience")}
                      className={`inline-flex items-center ${currentColor.icon} font-medium group`}
                      aria-label={`Learn more about ${skill.title} experience and projects`}
                    >
                      View {skill.title} Projects
                      <motion.span
                        initial={{ x: 0 }}
                        whileHover={{ x: 5 }}
                        transition={{ type: "spring", stiffness: 300 }}
                      >
                        <ArrowRight className="ml-2 w-4 h-4" />
                    </motion.span>
                    </Link>
                  </div>

                  {/* Decorative elements */}
                  <motion.div
                    initial={{ opacity: 0, scale: 0.8 }}
                    whileInView={{ opacity: 0.5, scale: 1 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.8 }}
                    className={`absolute -top-4 -right-4 w-20 h-20 ${currentColor.border} rounded-full blur-xl`}
                  />
                  <motion.div
                    initial={{ opacity: 0, scale: 0.8 }}
                    whileInView={{ opacity: 0.5, scale: 1 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.8, delay: 0.2 }}
                    className={`absolute -bottom-4 -left-4 w-24 h-24 ${currentColor.border} rounded-full blur-xl`}
                  />
                </motion.div>
              );
            })}
          </div>
        </div>
      </section>

      {/* Additional sections with lazy loading */}
      <section
        ref={skillsRef}
        className={`py-12 md:py-16 transition-opacity duration-700 ${
          skillsVisible ? 'opacity-100' : 'opacity-0'
        }`}
        aria-label="Skills"
      >
        {/* Skills content */}
      </section>
  
      <section
        ref={workRef}
        className={`py-12 md:py-16 transition-opacity duration-700 ${
          workVisible ? 'opacity-100' : 'opacity-0'
        }`}
        aria-label="Featured Work"
      >
        {/* Featured work content */}
      </section>
      </div>
    </> // Added Fragment closing tag
  );
}
